__author__ = "Dilawar Singh"
__email__ = "me@dilawars.me"

import wave
from pathlib import Path
import typing as T

def spectrogram(wavefile : str, nfft : int = 512, stride : int = 256):
    pass


def test_spectrogram():
    pass

if __name__ == "__main__":
    main()

